@@ -4,8 +4,8 @@ from django.contrib.admin.templatetags.admin_urls import admin_urlname
 from django.http import HttpResponseRedirect
 from django.urls import reverse
 
-from admin_extra_urls.api import button
-from admin_extra_urls.mixins import _confirm_action, ExtraUrlMixin
+from admin_extra_urls.api import ExtraUrlMixin, UrlButton, confirm_action, url
+from admin_extra_urls.decorators import button
 
 from .models import DemoModel1, DemoModel2, DemoModel3, DemoModel4
 from .upload import UploadMixin
@@ -28,58 +28,58 @@ class TestFilter(SimpleListFilter):
 class Admin1(ExtraUrlMixin, admin.ModelAdmin):
     list_filter = [TestFilter]
 
-    @button(label='Refresh', permission='demo.add_demomodel1')
+    @url(permission='demo.add_demomodel1', button=True)
     def refresh(self, request):
         opts = self.model._meta
         self.message_user(request, 'refresh called')
         return HttpResponseRedirect(reverse(admin_urlname(opts, 'changelist')))
 
-    @button(label='Refresh', permission=lambda request, object: False)
+    @url(button=UrlButton(label='Refresh'), permission=lambda request, object: False)
     def refresh_callable(self, request):
         opts = self.model._meta
         self.message_user(request, 'refresh called')
         return HttpResponseRedirect(reverse(admin_urlname(opts, 'changelist')))
 
-    @button(path='a/b')
+    @button(path='a/b/', button=True)
     def custom_path(self, request):
         opts = self.model._meta
         self.message_user(request, 'refresh called')
         return HttpResponseRedirect(reverse(admin_urlname(opts, 'changelist')))
 
-    @button()
+    @url(button=True)
     def no_response(self, request):
         self.message_user(request, 'No_response')
 
-    @button()
+    @url(button=True)
     def confirm(self, request):
         def _action(request):
             pass
 
-        return _confirm_action(self, request, _action, "Confirm action",
-                               "Successfully executed", )
+        return confirm_action(self, request, _action, "Confirm action",
+                              "Successfully executed", )
 
 
 class Admin2(ExtraUrlMixin, admin.ModelAdmin):
     list_filter = [TestFilter]
 
-    @button(permission='demo_delete_demomodel2')
+    @url(permission='demo_delete_demomodel2', button=True, details=True)
     def update(self, request, pk):
         opts = self.model._meta
         self.message_user(request, 'action called')
         return HttpResponseRedirect(reverse(admin_urlname(opts, 'changelist')))
 
-    @button()
-    def no_response(self, request, pk):
+    @url(button=True)
+    def no_response(self, request, object_id):
         self.message_user(request, 'No_response')
 
-    @button(permission=lambda request, obj: False)
-    def update_callable_permission(self, request, pk):
+    @url(permission=lambda request, obj: False)
+    def update_callable_permission(self, request, object_id):
         opts = self.model._meta
         self.message_user(request, 'action called')
         return HttpResponseRedirect(reverse(admin_urlname(opts, 'changelist')))
 
-    @button(path='a/b')
-    def custom_update(self, request, pk):
+    @url(path='a/b/<path:object_id>', button=True)
+    def custom_update(self, request, object_id):
         opts = self.model._meta
         self.message_user(request, 'action called')
         return HttpResponseRedirect(reverse(admin_urlname(opts, 'changelist')))
